==> create-fly-1.21.8-6.0.8-2-sources.jar: com/zurrtum/create/infrastructure/packet/s2c/MountedStorageSyncPacket.java <==
package com.zurrtum.create.infrastructure.packet.s2c;

import com.zurrtum.create.AllClientHandle;
import com.zurrtum.create.AllPackets;
import com.zurrtum.create.api.contraption.storage.fluid.MountedFluidStorage;
import com.zurrtum.create.api.contraption.storage.item.MountedItemStorage;
import org.apache.logging.log4j.util.TriConsumer;

import java.util.HashMap;
import java.util.Map;
import net.minecraft.class_2338;
import net.minecraft.class_9129;
import net.minecraft.class_9135;
import net.minecraft.class_9139;
import net.minecraft.class_9145;

public record MountedStorageSyncPacket(
    int contraptionId, Map<class_2338, MountedItemStorage> items, Map<class_2338, MountedFluidStorage> fluids
) implements S2CPacket {
    public static final class_9139<class_9129, MountedStorageSyncPacket> CODEC = class_9139.method_56436(
        class_9135.field_49675,
        MountedStorageSyncPacket::contraptionId,
        class_9135.method_56377(HashMap::new, class_2338.field_48404, MountedItemStorage.STREAM_CODEC),
        MountedStorageSyncPacket::items,
        class_9135.method_56377(HashMap::new, class_2338.field_48404, MountedFluidStorage.STREAM_CODEC),
        MountedStorageSyncPacket::fluids,
        MountedStorageSyncPacket::new
    );

    @Override
    public <T> TriConsumer<AllClientHandle<T>, T, MountedStorageSyncPacket> callback() {
        return AllClientHandle::onMountedStorageSync;
    }

    @Override
    public class_9145<MountedStorageSyncPacket> method_65080() {
        return AllPackets.MOUNTED_STORAGE_SYNC;
    }
}

==> create-fly-1.21.10-6.0.8-5-sources.jar: com/zurrtum/create/infrastructure/packet/s2c/MountedStorageSyncPacket.java <==
package com.zurrtum.create.infrastructure.packet.s2c;

import com.zurrtum.create.AllClientHandle;
import com.zurrtum.create.AllPackets;
import com.zurrtum.create.api.contraption.storage.fluid.MountedFluidStorage;
import com.zurrtum.create.api.contraption.storage.item.MountedItemStorage;
import java.util.HashMap;
import java.util.Map;
import net.minecraft.class_2338;
import net.minecraft.class_2596;
import net.minecraft.class_2602;
import net.minecraft.class_9129;
import net.minecraft.class_9135;
import net.minecraft.class_9139;
import net.minecraft.class_9145;

public record MountedStorageSyncPacket(
    int contraptionId, Map<class_2338, MountedItemStorage> items, Map<class_2338, MountedFluidStorage> fluids
) implements class_2596<class_2602> {
    public static final class_9139<class_9129, MountedStorageSyncPacket> CODEC = class_9139.method_56436(
        class_9135.field_49675,
        MountedStorageSyncPacket::contraptionId,
        class_9135.method_56377(HashMap::new, class_2338.field_48404, MountedItemStorage.STREAM_CODEC),
        MountedStorageSyncPacket::items,
        class_9135.method_56377(HashMap::new, class_2338.field_48404, MountedFluidStorage.STREAM_CODEC),
        MountedStorageSyncPacket::fluids,
        MountedStorageSyncPacket::new
    );

    @Override
    public void apply(class_2602 listener) {
        AllClientHandle.INSTANCE.onMountedStorageSync(this);
    }

    @Override
    public class_9145<MountedStorageSyncPacket> method_65080() {
        return AllPackets.MOUNTED_STORAGE_SYNC;
    }
}
